@@ -60,6 +60,7 @@ class HttpCli(object):
         self.bufsz = 1024 * 32
         self.hint = None
         self.trailing_slash = True
+        self.out_headerlist = []
         self.out_headers = {
             "Access-Control-Allow-Origin": "*",
             "Cache-Control": "no-store; max-age=0",
@@ -91,6 +92,7 @@ class HttpCli(object):
         tpl = self.conn.hsrv.j2[name]
         if ka:
             ka["ts"] = self.conn.hsrv.cachebuster()
+            ka["svcname"] = self.args.doctitle
             return tpl.render(**ka)
 
         return tpl
@@ -226,7 +228,7 @@ class HttpCli(object):
         self.gvol = self.asrv.vfs.aget[self.uname]
 
         if pwd and "pw" in self.ouparam and pwd != cookies.get("cppwd"):
-            self.out_headers["Set-Cookie"] = self.get_pwd_cookie(pwd)[0]
+            self.out_headerlist.append(("Set-Cookie", self.get_pwd_cookie(pwd)[0]))
 
         self.ua = self.headers.get("user-agent", "")
         self.is_rclone = self.ua.startswith("rclone/")
@@ -285,7 +287,7 @@ class HttpCli(object):
         self.out_headers["Cache-Control"] = "max-age=" + n
 
     def k304(self):
-        k304 = self.cookies.get("k304", "")
+        k304 = self.cookies.get("k304")
         return k304 == "y" or ("; Trident/" in self.ua and not k304)
 
     def send_headers(self, length, status=200, mime=None, headers=None):
@@ -310,7 +312,7 @@ class HttpCli(object):
 
         self.out_headers["Content-Type"] = mime
 
-        for k, v in self.out_headers.items():
+        for k, v in list(self.out_headers.items()) + self.out_headerlist:
             response.append("{}: {}".format(k, v))
 
         try:
@@ -439,6 +441,12 @@ class HttpCli(object):
             if "k304" in self.uparam:
                 return self.set_k304()
 
+            if "am_js" in self.uparam:
+                return self.set_am_js()
+
+            if "reset" in self.uparam:
+                return self.set_cfg_reset()
+
             if "h" in self.uparam:
                 return self.tx_mounts()
 
@@ -516,7 +524,7 @@ class HttpCli(object):
                 return self.handle_stash()
 
             if "save" in opt:
-                post_sz, _, _, _, path = self.dump_to_file()
+                post_sz, _, _, _, path, _ = self.dump_to_file()
                 self.log("urlform: {} bytes, {}".format(post_sz, path))
             elif "print" in opt:
                 reader, _ = self.get_body_reader()
@@ -643,26 +651,46 @@ class HttpCli(object):
                 bos.unlink(path)
                 raise
 
-        if not self.args.nw:
-            vfs, vrem = vfs.get_dbv(rem)
-            self.conn.hsrv.broker.put(
-                False,
-                "up2k.hash_file",
-                vfs.realpath,
-                vfs.flags,
-                vrem,
-                fn,
-                self.ip,
-                time.time(),
-            )
+        if self.args.nw:
+            return post_sz, sha_hex, sha_b64, remains, path, ""
 
-        return post_sz, sha_hex, sha_b64, remains, path
+        vfs, rem = vfs.get_dbv(rem)
+        self.conn.hsrv.broker.put(
+            False,
+            "up2k.hash_file",
+            vfs.realpath,
+            vfs.flags,
+            rem,
+            fn,
+            self.ip,
+            time.time(),
+        )
+
+        vsuf = ""
+        if self.can_read and "fk" in vfs.flags:
+            vsuf = "?k=" + gen_filekey(
+                self.args.fk_salt,
+                path,
+                post_sz,
+                0 if ANYWIN else bos.stat(path).st_ino,
+            )[: vfs.flags["fk"]]
+
+        vpath = "/".join([x for x in [vfs.vpath, rem, fn] if x])
+        vpath = quotep(vpath)
+
+        url = "{}://{}/{}".format(
+            "https" if self.is_https else "http",
+            self.headers.get("host") or "{}:{}".format(*list(self.s.getsockname())),
+            vpath + vsuf,
+        )
+
+        return post_sz, sha_hex, sha_b64, remains, path, url
 
     def handle_stash(self):
-        post_sz, sha_hex, sha_b64, remains, path = self.dump_to_file()
+        post_sz, sha_hex, sha_b64, remains, path, url = self.dump_to_file()
         spd = self._spd(post_sz)
         self.log("{} wrote {}/{} bytes to {}".format(spd, post_sz, remains, path))
-        m = "{}\n{}\n{}\n".format(post_sz, sha_b64, sha_hex[:56])
+        m = "{}\n{}\n{}\n{}\n".format(post_sz, sha_b64, sha_hex[:56], url)
         self.reply(m.encode("utf-8"))
         return True
 
@@ -1162,11 +1190,12 @@ class HttpCli(object):
                 )[: vfs.flags["fk"]]
 
             vpath = "{}/{}".format(upload_vpath, lfn).strip("/")
+            rel_url = quotep(vpath) + vsuf
             msg += 'sha512: {} // {} // {} bytes // <a href="/{}">{}</a> {}\n'.format(
                 sha_hex[:56],
                 sha_b64,
                 sz,
-                quotep(vpath) + vsuf,
+                rel_url,
                 html_escape(ofn, crlf=True),
                 vsuf,
             )
@@ -1175,15 +1204,16 @@ class HttpCli(object):
             jpart = {
                 "url": "{}://{}/{}".format(
                     "https" if self.is_https else "http",
-                    self.headers.get("host", "copyparty"),
-                    vpath + vsuf,
+                    self.headers.get("host")
+                    or "{}:{}".format(*list(self.s.getsockname())),
+                    rel_url,
                 ),
                 "sha512": sha_hex[:56],
                 "sha_b64": sha_b64,
                 "sz": sz,
                 "fn": lfn,
                 "fn_orig": ofn,
-                "path": vpath + vsuf,
+                "path": rel_url,
             }
             jmsg["files"].append(jpart)
 
@@ -1359,6 +1389,9 @@ class HttpCli(object):
             try:
                 fs_path = req_path + ext
                 st = bos.stat(fs_path)
+                if stat.S_ISDIR(st.st_mode):
+                    continue
+
                 file_ts = max(file_ts, st.st_mtime)
                 editions[ext or "plain"] = [fs_path, st.st_size]
             except:
@@ -1504,11 +1537,12 @@ class HttpCli(object):
         with open_func(*open_args) as f:
             sendfun = sendfile_kern if use_sendfile else sendfile_py
             remains = sendfun(
-                lower, upper, f, self.s, self.args.s_wr_sz, self.args.s_wr_slp
+                self.log, lower, upper, f, self.s, self.args.s_wr_sz, self.args.s_wr_slp
             )
 
         if remains > 0:
             logmsg += " \033[31m" + unicode(upper - remains) + "\033[0m"
+            self.keepalive = False
 
         spd = self._spd((upper - lower) - remains)
         if self.do_log:
@@ -1717,7 +1751,19 @@ class HttpCli(object):
 
     def set_k304(self):
         ck = gencookie("k304", self.uparam["k304"], 60 * 60 * 24 * 365)
-        self.out_headers["Set-Cookie"] = ck
+        self.out_headerlist.append(("Set-Cookie", ck))
+        self.redirect("", "?h#cc")
+
+    def set_am_js(self):
+        v = "n" if self.uparam["am_js"] == "n" else "y"
+        ck = gencookie("js", v, 60 * 60 * 24 * 365)
+        self.out_headerlist.append(("Set-Cookie", ck))
+        self.reply(b"promoted\n")
+
+    def set_cfg_reset(self):
+        for k in ("k304", "js", "cppwd"):
+            self.out_headerlist.append(("Set-Cookie", gencookie(k, "x", None)))
+
         self.redirect("", "?h#cc")
 
     def tx_404(self, is_403=False):
@@ -1939,6 +1985,13 @@ class HttpCli(object):
                 fmt = "{{}}  {{:{},}}  {{}}"
                 nfmt = "{:,}"
 
+            for x in dirs:
+                n = x["name"] + "/"
+                if arg == "v":
+                    n = "\033[94m" + n
+
+                x["name"] = n
+
             fmt = fmt.format(len(nfmt.format(biggest)))
             ret = [
                 "# {}: {}".format(x, ls[x])
@@ -2077,6 +2130,7 @@ class HttpCli(object):
 
         url_suf = self.urlq({}, [])
         is_ls = "ls" in self.uparam
+        is_js = self.cookies.get("js") == "y"
 
         tpl = "browser"
         if "b" in self.uparam:
@@ -2105,6 +2159,7 @@ class HttpCli(object):
             "taglist": [],
             "srvinf": srv_info,
             "acct": self.uname,
+            "idx": ("e2d" in vn.flags),
             "perms": perms,
             "logues": logues,
             "readme": readme,
@@ -2113,6 +2168,7 @@ class HttpCli(object):
             "vdir": quotep(self.vpath),
             "vpnodes": vpnodes,
             "files": [],
+            "ls0": None,
             "acct": self.uname,
             "perms": json.dumps(perms),
             "taglist": [],
@@ -2193,7 +2249,7 @@ class HttpCli(object):
         for fn in vfs_ls:
             base = ""
             href = fn
-            if not is_ls and not self.trailing_slash and vpath:
+            if not is_ls and not is_js and not self.trailing_slash and vpath:
                 base = "/" + vpath + "/"
                 href = base + fn
 
@@ -2336,7 +2392,12 @@ class HttpCli(object):
 
         dirs.sort(key=itemgetter("name"))
 
-        j2a["files"] = dirs + files
+        if is_js:
+            j2a["ls0"] = {"dirs": dirs, "files": files, "taglist": taglist}
+            j2a["files"] = []
+        else:
+            j2a["files"] = dirs + files
+
         j2a["logues"] = logues
         j2a["taglist"] = taglist
         j2a["txt_ext"] = self.args.textfiles.replace(",", " ")
