@@ -86,6 +86,9 @@ function vis_exh(msg, url, lineNo, columnNo, error) {
     if ((msg + '').indexOf('ResizeObserver') !== -1)
         return;  // chrome issue 809574 (benign, from <video>)
 
+    if ((msg + '').indexOf('l2d.js') !== -1)
+        return;  // `t` undefined in tapEvent -> hitTestSimpleCustom
+
     var ekey = url + '\n' + lineNo + '\n' + msg;
     if (ignexd[ekey] || crashed)
         return;
@@ -219,15 +222,15 @@ if (!String.prototype.endsWith)
         return this.substring(this_len - search.length, this_len) === search;
     };
 
-if (!String.startsWith)
+if (!String.prototype.startsWith)
     String.prototype.startsWith = function (s, i) {
         i = i > 0 ? i | 0 : 0;
         return this.substring(i, i + s.length) === s;
     };
 
-if (!String.trimEnd)
+if (!String.prototype.trimEnd)
     String.prototype.trimEnd = String.prototype.trimRight = function () {
-        return this.replace(/[ \t\r\n]+$/m, '');
+        return this.replace(/[ \t\r\n]+$/, '');
     };
 
 if (!Element.prototype.matches)
@@ -329,14 +332,45 @@ function clgot(el, cls) {
 }
 
 
+function showsort(tab) {
+    var v, vn, v1, v2, th = tab.tHead,
+        sopts = jread('fsort', [["href", 1, ""]]);
+
+    th && (th = th.rows[0]) && (th = th.cells);
+
+    for (var a = sopts.length - 1; a >= 0; a--) {
+        if (!sopts[a][0])
+            continue;
+
+        v2 = v1;
+        v1 = sopts[a];
+    }
+
+    v = [v1, v2];
+    vn = [v1 ? v1[0] : '', v2 ? v2[0] : ''];
+
+    var ga = QSA('#ghead a[s]');
+    for (var a = 0; a < ga.length; a++)
+        ga[a].className = '';
+
+    for (var a = 0; a < th.length; a++) {
+        var n = vn.indexOf(th[a].getAttribute('name')),
+            cl = n < 0 ? ' ' : ' s' + n + (v[n][1] > 0 ? ' ' : 'r ');
+
+        th[a].className = th[a].className.replace(/ *s[01]r? */, ' ') + cl;
+        if (n + 1) {
+            ga = QS('#ghead a[s="' + vn[n] + '"]');
+            if (ga)
+                ga.className = cl;
+        }
+    }
+}
 function sortTable(table, col, cb) {
     var tb = table.tBodies[0],
         th = table.tHead.rows[0].cells,
         tr = Array.prototype.slice.call(tb.rows, 0),
-        i, reverse = th[col].className.indexOf('sort1') !== -1 ? -1 : 1;
-    for (var a = 0, thl = th.length; a < thl; a++)
-        th[a].className = th[a].className.replace(/ *sort-?1 */, " ");
-    th[col].className += ' sort' + reverse;
+        i, reverse = /s0[^r]/.exec(th[col].className + ' ') ? -1 : 1;
+
     var stype = th[col].getAttribute('sort');
     try {
         var nrules = [], rules = jread("fsort", []);
@@ -354,6 +388,7 @@ function sortTable(table, col, cb) {
                 break;
         }
         jwrite("fsort", nrules);
+        try { showsort(table); } catch (ex) { }
     }
     catch (ex) {
         console.log("failed to persist sort rules, resetting: " + ex);
@@ -402,7 +437,7 @@ function makeSortable(table, cb) {
 }
 
 
-function linksplit(rp) {
+function linksplit(rp, id) {
     var ret = [],
         apath = '/',
         q = null;
@@ -432,8 +467,13 @@ function linksplit(rp) {
             vlink = vlink.slice(0, -1) + '<span>/</span>';
         }
 
-        if (!rp && q)
-            link += q;
+        if (!rp) {
+            if (q)
+                link += q;
+
+            if (id)
+                link += '" id="' + id;
+        }
 
         ret.push('<a href="' + apath + link + '">' + vlink + '</a>');
         apath += link;
