@@ -29,6 +29,9 @@ class Cfg(Namespace):
             v=v or [],
             c=c,
             rproxy=0,
+            rsp_slp=0,
+            s_wr_slp=0,
+            s_wr_sz=512 * 1024,
             ed=False,
             nw=False,
             unpost=600,
@@ -48,6 +51,7 @@ class Cfg(Namespace):
             mte="a",
             mth="",
             textfiles="",
+            doctitle="",
             hist=None,
             no_idx=None,
             no_hash=None,
